@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::CompileTests;
 BEGIN {
-  $Dist::Zilla::Plugin::CompileTests::VERSION = '1.103030';
+  $Dist::Zilla::Plugin::CompileTests::VERSION = '1.110870';
 }
 # ABSTRACT: common tests to check syntax of your modules
 
@@ -58,7 +58,7 @@ CODE
 
     # replace strings in the file
     my $content = $file->content;
-    $content =~ s/COMPILETESTS_SKIP/$skip/;
+    $content =~ s/COMPILETESTS_SKIP/$skip/g;
     $content =~ s/COMPILETESTS_FAKE_HOME/$home/;
     $content =~ s/COMPILETESTS_NEEDS_DISPLAY/$needs_display/;
     $file->content( $content );
@@ -80,7 +80,7 @@ Dist::Zilla::Plugin::CompileTests - common tests to check syntax of your modules
 
 =head1 VERSION
 
-version 1.103030
+version 1.110870
 
 =head1 SYNOPSIS
 
@@ -194,7 +194,16 @@ find(
   'lib',
 );
 
-my @scripts = glob "bin/*";
+my @scripts;
+find(
+  sub {
+    return unless -f;
+    my $found = $File::Find::name;
+    COMPILETESTS_SKIP
+    push @scripts, $found;
+  },
+  'bin',
+);
 
 my $plan = scalar(@modules) + scalar(@scripts);
 $plan ? (plan tests => $plan) : (plan skip_all => "no tests to run");
